#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2006, 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Определите переменные среды, соответствующие параметрам
# # сценария rm_upgrade.sh, и их значения по умолчанию
# #
# #===========================================================
# #
# # Этот файл считывается в начале каждого выполнения сценария
# # rm_upgrade.sh. Для каждого допустимого параметра он
# # инициализирует переменную среды предопределенным
# # значением по умолчанию.
# #
# # Пользователям может потребоваться изменить значение по
# # умолчанию, чтобы запускать rm_upgrade.sh со своими
# # значениями, не вводя параметр и его значение вручную
# # в командной строке.
# #
# # ПРЕДУПРЕЖДЕНИЕ:
# # Для некоторых приложений требуется указывать не все
# # переменные.  Внимательно ознакомьтесь с комментарием
# # перед изменением значения.
# #
# #############################################################

# Параметр: -oldApplicationHome
# Формат: -oldApplicationHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу приложения в
#  предыдущей версии.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - это обязательный параметр
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf',
#    например: /Jazz/IBM/RRC_3.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# Параметр: -applicationContextRoot
# Формат: -applicationContextRoot <корневой-контекст>
# Описание:
# 	Корневой контекст приложения.
# Значение по умолчанию:
# 	rm
# Ограничения:
#  - <корневой-контекст> должен быть коротким именем каталога
#   (то есть без начальной косой черты)
#
APPLICATION_CONTEXT_ROOT=

# Параметр: -oldJTSHome
# Формат: -oldJTSHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу JTS в предыдущей версии.
# По умолчанию:
# 	<нет>
# Ограничения:
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf'
#  - Допустим только при обновлении RM и JTS
#
OLD_JTS_HOME=

# Параметр: -oldJTSContextRoot
# Формат: -oldJTSContextRoot <корневой-контекст>
# Описание:
# 	Корневой контекст JTS предыдущей версии.
# Значение по умолчанию:
# 	jts
# Ограничения:
#  - Допустим только при обновлении RM
#  - <корневой-контекст> должен быть коротким именем каталога
#    (то есть без начальной косой черты)
#
OLD_JTS_CONTEXT_ROOT=

# Параметр: -updateTomcatFiles
# Формат: -updateTomcatFiles <yes | no>
# Описание:
# 	Разрешает/запрещает обновление файлов конфигурации Tomcat.
# Значение по умолчанию:
# 	yes
# Ограничения:
#  - Допустимы только значения 'yes' и 'no'
#
UPDATE_TOMCAT_FILES=yes

# Параметр: -oldApplicationTomcatHome
# Формат: -oldApplicationTomcatHome <путь-к-каталогу>
# Описание:
# 	Полный путь к корневому каталогу Tomcat приложения в предыдущей
#  версии.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустим только при обновлении RM
#  - Должен задавать существующий каталог
#
OLD_TOMCAT_HOME=

# Параметр: -oldJTSTomcatHome
# Формат: -oldJTSTomcatHome <путь-к-каталогу>
# Описание:
# 	Полный путь к корневому каталогу Tomcat JTS в предыдущей версии.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустим только при обновлении RM
#  - Должен задавать существующий каталог
#
OLD_JTS_TOMCAT_HOME=

# Параметр: -newApplicationHome
# Формат: -newApplicationHome <путь-к-каталогу>
# Описание:
# 	Путь к домашнему каталогу приложения в новой версии.
# Значение по умолчанию:
# 	conf
# Ограничения:
#  - Допустим только при обновлении RTC, QM и RM
#  - Если допустим, то является обязательным
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf',
#    например: /Jazz/IBM/RRC_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Параметр: -newJTSHome
# Формат: -newJTSHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу JTS в новой версии.
# Значение по умолчанию:
# 	Новый домашний каталог приложения
# Ограничения:
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf'
#
NEW_JTS_HOME=

# Параметр: -newJTSContextRoot
# Формат: -newJTSContextRoot <корневой-контекст>
# Описание:
# 	Корневой контекст сервера JTS новой версии.
# Значение по умолчанию:
# 	jts
# Ограничения:
#  - <корневой-контекст> должен быть коротким именем каталога
#   (то есть без начальной косой черты)
#
JTS_CONTEXT_ROOT=jts

# Параметр: -newApplicationTomcatHome
# Формат: -newApplicationTomcatHome <путь-к-каталогу>
# Описание:
# 	Путь к корневому каталогу Tomcat приложения в новой версии.
# Значение по умолчанию:
# 	<нет>
#
NEW_TOMCAT_HOME=

# Параметр: -newJTSTomcatHome
# Формат: -newJTSTomcatHome <путь-к-каталогу>
# Описание:
# 	Путь к корневому каталогу Tomcat JTS в новой версии.
# Значение по умолчанию:
# 	<нет>
#
NEW_JTS_TOMCAT_HOME=

# Параметр: -noPrompt
# Формат: -noPrompt
# Описание:
# 	Не показывать никаких приглашений (всегда использовать noPrompt) при выполнении команд repotools
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Параметр: -overwrite
# Формат: -overwrite
# Описание:
# 	Принудительная замена (всегда использовать overwrite=yes) при выполнении команд repotools
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Параметр: -noVerify
# Формат: -noVerify
# Описание:
# 	Не выполнять никаких проверок (всегда использовать noVerify) при выполнении команд repotools
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Параметр: -noStepPrompt
# Формат: -noStepPrompt
# Описание:
# 	Не выводить запрос перед каждым этапом обновления
# Значение по умолчанию:
# 	false
# Ограничения:
#  - Допустимы только значения 'true' и 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false

# Параметр: -jtsURL
# Формат: -jtsURL <внешний URI JTS>
# Описание:
# 	внешний URI JTS
# По умолчанию:
# 	<нет>
# Ограничения:
#  - Действует только для обновления RM
#  - Необходим только в распределенной среде, где JTS и приложение RM работают на разных серверах
#
JTS_PUBLIC_URL=
